openedX
=======

`openedX <https://open.edx.org/>`__ is available at
`openedx.example.com`. The user with administrative rights and the
contact email are defined as documented in `this file
<https://lab.enough.community/main/infrastructure/blob/master/playbooks/openedx/roles/openedx/defaults/main.yml>`__
and can be modified in the
`~/.enough/example.com/inventory/group_vars/openedx-service-group.yml`
file.
